@@ -1,7 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
+
 from . import price_list
+from .price_list import Null
+
+__all__ = ['register', 'Null']
 
 
 def register():
